@@ -183,7 +183,7 @@ class TaskQueue(object):
     )
 
     def insertfn(batch):
-        return self.api.insert(batch, delay_seconds) 
+      return self.api.insert(batch, delay_seconds) 
     
     cts = schedule_jobs(
       fns=( partial(insertfn, batch) for batch in sip(bodies, batch_size) ),
@@ -191,7 +191,6 @@ class TaskQueue(object):
       progress=('Inserting' if self.progress else False),
       total=total,
       green=self.green,
-      batch_size=batch_size,
     )
     cts = sum(cts)
 
@@ -220,7 +219,7 @@ class TaskQueue(object):
   def release_all(self):
     return self.api.release_all()
 
-  def lease(self, seconds=600, num_tasks=1):
+  def lease(self, seconds=600, num_tasks=1, wait_sec=None):
     """
     Acquires a lease on the topmost N unowned tasks in the specified queue.
     Required query parameters: leaseSecs, numTasks
@@ -230,7 +229,7 @@ class TaskQueue(object):
     if seconds < 0:
       raise ValueError("lease seconds must be >= 0. Got: " + str(seconds))
 
-    tasks = self.api.lease(seconds, num_tasks)
+    tasks = self.api.lease(seconds, num_tasks, wait_sec)
 
     if not len(tasks):
       raise QueueEmptyError()
@@ -246,9 +245,10 @@ class TaskQueue(object):
     total = totalfn(task_id, total)
 
     def deltask(tid):
-      self.api.delete(totaskid(tid))
+      num_deleted = self.api.delete(totaskid(tid))
       if tally:
         self.api.tally()
+      return num_deleted
 
     schedule_jobs(
       fns=( partial(deltask, tid) for tid in task_id ),
@@ -563,7 +563,7 @@ def multiprocess_upload(QueueClass, queue_name, tasks, parallel=True, total=None
   ct = 0
   with tqdm(desc="Upload", total=total) as pbar:
     with pathos.pools.ProcessPool(parallel) as pool:
-      for num_inserted in pool.imap(uploadfn, sip(tasks, 2000)):
+      for num_inserted in pool.imap(uploadfn, sip(tasks, block_size)):
         pbar.update(num_inserted)
         ct += num_inserted
 
@@ -584,5 +584,13 @@ def multiprocess_upload(QueueClass, queue_name, tasks, parallel=True, total=None
 
   return ct
 
+# c/o https://stackoverflow.com/questions/12826291/raise-two-errors-at-the-same-time
+def raise_multiple(errors):
+  if not errors:
+    return
+  try:
+    raise errors.pop()
+  finally:
+    raise_multiple(errors)
 
 
